"""Example for moving a robot."""

from voraus_robot_arm import JointPose, VorausIndustrialRobotArm, x

robot = VorausIndustrialRobotArm()
home = JointPose(0, -1.57, 1.57, -1.57, -1.57, 0)

if __name__ == "__main__":
    robot = VorausIndustrialRobotArm()
    with robot.connect("voraus-core", port=48401):
        robot.enable()
        robot.move_ptp(home).result()

        input("Press enter to move the robot.")
        robot.move_linear_relative(x(0.2)).result()
